AccountReportMethods

Struct AccountReportMethods 

pub struct AccountReportMethods<'a, C>
where C: 'a,
{ /* private fields */ }
A builder providing access to all methods supported on accountReport resources. It is not used directly, but through the Localservices hub.

Example

Instantiate a resource builder

extern crate hyper;
extern crate hyper_rustls;
extern crate google_localservices1 as localservices1;

use localservices1::{Localservices, FieldMask, hyper_rustls, hyper_util, yup_oauth2};

let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
    .with_native_roots()
    .unwrap()
    .https_only()
    .enable_http2()
    .build();

let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
    secret,
    yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
    yup_oauth2::client::CustomHyperClientBuilder::from(
        hyper_util::client::legacy::Client::builder(executor).build(connector),
    ),
).build().await.unwrap();

let client = hyper_util::client::legacy::Client::builder(
    hyper_util::rt::TokioExecutor::new()
)
.build(
    hyper_rustls::HttpsConnectorBuilder::new()
        .with_native_roots()
        .unwrap()
        .https_or_http()
        .enable_http2()
        .build()
);
let mut hub = Localservices::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `search(...)`
// to build up your call.
let rb = hub.account_reports();

Implementations

Source

impl<'a, C> AccountReportMethods<'a, C>

pub fn search(&self) -> AccountReportSearchCall<'a, C>

Create a builder to help you perform the following task:

Get account reports containing aggregate account data of all linked GLS accounts. Caller needs to provide their manager customer id and the associated auth credential that allows them read permissions on their linked accounts.